@@ -1,5 +1,5 @@
 from request import get
-from request import request
+from request import request_json
 
 from database import connect_db
 from database import create_db
